import { world, system } from "@minecraft/server";

world.beforeEvents.chatSend.subscribe((eventData) => {
    const message = eventData.message;
    const player = eventData.sender;

    if (message.startsWith("#size ")) {
        const args = message.split(" ");
        const sizeInput = args[1];
        const noCam = args.includes("nocam"); // Check if "nocam" argument is present

        if (sizeInput.toLowerCase() === "reset") {
            let scaleValue = 1;
            system.run(() => {
                player.getComponent("minecraft:scale").value = scaleValue;
                if (noCam) {
                    // Reset camera perspective if "nocam" is used
                    player.runCommandAsync(`camera @s clear`);
                }
            });
            player.sendMessage("§aSize reset to default (1).");
            eventData.cancel = true;
            return;
        }

        let targetScaleValue = parseFloat(sizeInput);
        if (!isNaN(targetScaleValue) && targetScaleValue > 0) {
            if (targetScaleValue === 1) {
                system.run(() => {
                    player.getComponent("minecraft:scale").value = 1;
                    if (noCam) {
                        // Reset camera perspective if "nocam" is used
                        player.runCommandAsync(`camera @s clear`);
                    }
                });
                player.sendMessage("§aSize reset to default (1).");
            } else {
                system.run(() => {
                    const playerScaleComponent = player.getComponent("minecraft:scale");
                    let currentScaleValue = playerScaleComponent.value;
                    const increment = 0.1; // Amount to change per tick

                    const smoothScaleChange = () => {
                        let difference = targetScaleValue - currentScaleValue;
                        if (Math.abs(difference) <= increment) {
                            currentScaleValue = targetScaleValue;
                            playerScaleComponent.value = targetScaleValue;

                            if (!noCam) {
                                // Adjust camera only if not in "nocam" mode
                                player.runCommandAsync(
                                    `camera @s set minecraft:follow_orbit view_offset 0 0 entity_offset 0 ${targetScaleValue} 0`
                                );
                            } else {
                                // Reset camera perspective if "nocam" is used
                                player.runCommandAsync(`camera @s clear`);
                            }
                            player.sendMessage(`§aSize set to ${targetScaleValue}.`);
                        } else {
                            currentScaleValue += (difference > 0 ? increment : -increment);
                            playerScaleComponent.value = currentScaleValue;

                            if (!noCam) {
                                // Adjust camera only if not in "nocam" mode
                                player.runCommandAsync(
                                    `camera @s set minecraft:follow_orbit view_offset 0 0 entity_offset 0 ${currentScaleValue} 0`
                                );
                            }
                            system.run(smoothScaleChange);
                        }
                    };
                    smoothScaleChange();
                });
            }
        } else {
            player.sendMessage("§cInvalid size value. Please use a positive number.");
        }
        eventData.cancel = true;
    }
});